@@ -8,8 +8,8 @@ from openapi_schema_validator.validators import OAS31Validator
 
 __author__ = "Artur Maciag"
 __email__ = "maciag.artur@gmail.com"
-__version__ = "0.4.3"
-__url__ = "https://github.com/p1c2u/openapi-schema-validator"
+__version__ = "0.6.2"
+__url__ = "https://github.com/python-openapi/openapi-schema-validator"
 __license__ = "3-clause BSD License"
 
 __all__ = [
